pub struct Prophecy<T> { /* private fields */ }Expand description
A general-purpose prophecy variable.
A prophecy variable is allocated via Prophecy::new
and resolved to a definitive value via Prophecy::resolve.
In contrast to the similar ProphecyGhost, this does not require us to mark the
value() as verifier::prophetic, which can make it easier to use.
However, it does not allow dependent resolutions, and it can only resolve to values
which are computed purely in exec-mode (as enforced by the T: Structural bound).
See the module level documentation for a detailed comparison with the rationale
for these trade-offs.
Implementations
Sourceimpl<T> Prophecy<T>where
T: Structural,
impl<T> Prophecy<T>where
T: Structural,